olh1: orthogonal Latin hypercube designs

View source: R/SlicedLHD.R

olh1R Documentation

orthogonal Latin hypercube designs

Description

This function generates an orthogonal Latin hypercube designs upto 6 columns

Usage

olh1(n, m)

Arguments

n

number of runs

m

number of columns, between 2 to 6

Value

A orthogonal Latin hypercube design with m columns in n runs

Author(s)

Baidya Nath Mandal<mandal.stat@gmail.com>

Examples

olh1(16,3)

SlicedLHD documentation built on May 29, 2024, 3:50 a.m.

Related to olh1 in SlicedLHD...