| solh | R Documentation |
This function generates a sliced orthogonal Latin hypercube designs upto 6 columns
solh(n1, t, q)
n1 |
number of runs in first slice |
t |
number of slices, currently 3 or 4 are supported |
q |
number of columns, between 2 to 6 |
A sliced orthogonal Latin hypercube design with q columns in t(n1-1) + 1 runs in t slices
A Anil Kumar<aa9538148952@gmail.com>
solh(4,5,2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.