| olh1 | R Documentation |
This function generates an orthogonal Latin hypercube designs upto 6 columns
olh1(n, m)
n |
number of runs |
m |
number of columns, between 2 to 6 |
A orthogonal Latin hypercube design with m columns in n runs
Baidya Nath Mandal<mandal.stat@gmail.com>
olh1(16,3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.